@@ -54,7 +54,7 @@ see.exp.tck<-function ()
 }
 
 see.expcdf.tck<-function (){ 
-  old.par <- par(no.readonly = TRUE)
+#  old.par <- par(no.readonly = TRUE)
     if (!exists("slider.env")) 
         slider.env <- NULL; suppressWarnings(rm(slider.env)); slider.env <<- new.env()# Dummy to trick R CMD check 
     theta <- 1
@@ -107,5 +107,5 @@ see.expcdf.tck<-function (){
     tkpack(tkbutton(m, text = "Exit", command = function() tkdestroy(m)), 
         side = "right")
     
-    on.exit(par(old.par))
+ #   on.exit(par(old.par))
   }
\ No newline at end of file
